==> nextcloud-28.0.8.tgz: nextcloud/apps/weather_status/l10n/ga.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "Seoladh anaithnid",
    "No result." : "Gan toradh.",
    "Malformed JSON data." : "Sonraí JSON míchumtha.",
    "Error" : "Earráid",
    "Weather status" : "Stádas aimsire",
    "Weather status in your dashboard" : "Stádas aimsire i do dheais",
    "Weather status integrated in the Dashboard app.\n    The geographic location can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Stádas aimsire comhtháite san aip Deais.\nIs féidir an suíomh geografach a chinneadh go huathoibríoch nó a shainiú de láimh. Taispeántar réamhaisnéis 6 huaire ansin.\nIs féidir an stádas seo a chomhtháthú in áiteanna eile ar nós an aip Féilire.",
    "Detect location" : "Braith suíomh",
    "Set custom address" : "Socraigh seoladh saincheaptha",
    "Favorites" : "Ceanáin",
    "{temperature} {unit} clear sky later today" : "{temperature} {unit} spéir shoiléir níos déanaí inniu",
    "{temperature} {unit} clear sky" : "{temperature} {unit} spéir shoiléir",
    "{temperature} {unit} cloudy later today" : "{temperature} {unit} scamallach níos déanaí inniu",
    "{temperature} {unit} cloudy" : "{temperature} {unit} scamallach",
    "{temperature} {unit} fair weather later today" : "{temperature} {unit} aimsir chothrom níos déanaí inniu",
    "{temperature} {unit} fair weather" : "{temperature} {unit} aimsir chothrom",
    "{temperature} {unit} partly cloudy later today" : "{temperature} {unit} beagán scamallach níos déanaí inniu",
    "{temperature} {unit} partly cloudy" : "{temperature} {unit} breacscamallach",
    "{temperature} {unit} foggy later today" : "{temperature} {unit} ceo níos déanaí inniu",
    "{temperature} {unit} foggy" : "{temperature} {unit} ceo",
    "{temperature} {unit} light rainfall later today" : "{temperature} {unit} báisteach éadrom níos déanaí inniu",
    "{temperature} {unit} light rainfall" : "{temperature} {unit} báisteach éadrom",
    "{temperature} {unit} rainfall later today" : "{temperature} {unit} báisteach níos déanaí inniu",
    "{temperature} {unit} rainfall" : "{temperature} {unit} báistí",
    "{temperature} {unit} heavy rainfall later today" : "{temperature} {unit} báisteach throm níos déanaí inniu",
    "{temperature} {unit} heavy rainfall" : "{temperature} {unit} báisteach throm",
    "{temperature} {unit} rainfall showers later today" : "{temperature} {unit} ceathanna báistí níos déanaí inniu",
    "{temperature} {unit} rainfall showers" : "{temperature} {unit} ceathanna báistí",
    "{temperature} {unit} light rainfall showers later today" : "{temperature} {unit} ceathanna báistí éadrom níos déanaí inniu",
    "{temperature} {unit} light rainfall showers" : "{temperature} {unit} cithfholcadáin báistí éadrom",
    "{temperature} {unit} heavy rainfall showers later today" : "{temperature} {unit} cithfholcadáin báistí trom níos déanaí inniu",
    "{temperature} {unit} heavy rainfall showers" : "{temperature} {unit} cithfholcadáin báistí trom",
    "More weather for {adr}" : "Tuilleadh aimsire le haghaidh {adr}",
    "Loading weather" : "Aimsir á lódáil",
    "Remove from favorites" : "Bain ó cheanáin",
    "Add as favorite" : "Cuir mar is fearr leat",
    "You are not logged in." : "Níl tú logáilte isteach.",
    "There was an error getting the weather status information." : "Tharla earráid agus an t-eolas ar stádas aimsire á fáil.",
    "No weather information found" : "Níor aimsíodh aon eolas aimsire",
    "Location not found" : "Suíomh gan aimsiú",
    "There was an error setting the location address." : "Tharla earráid agus an seoladh suímh á shocrú.",
    "There was an error setting the location." : "Tharla earráid agus an suíomh á shocrú.",
    "There was an error saving the mode." : "Tharla earráid agus an mód á shábháil.",
    "There was an error using personal address." : "Tharla earráid agus seoladh pearsanta á úsáid.",
    "Set location for weather" : "Socraigh suíomh don aimsir",
    "Weather status integrated in the Dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Stádas aimsire comhtháite san aip Deais.\nIs féidir seasamh an úsáideora a chinneadh go huathoibríoch nó a shainiú de láimh. Taispeántar réamhaisnéis 6 huaire ansin.\nIs féidir an stádas seo a chomhtháthú in áiteanna eile ar nós an aip Féilire."
},
"nplurals=5; plural=(n==1 ? 0 : n==2 ? 1 : n<7 ? 2 : n<11 ? 3 : 4);");

==> nextcloud-29.0.12.tgz: nextcloud/apps/weather_status/l10n/ga.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "Seoladh anaithnid",
    "No result." : "Gan toradh.",
    "Malformed JSON data." : "Sonraí JSON míchumtha.",
    "Error" : "Earráid",
    "Weather status" : "Stádas aimsire",
    "Weather status in your dashboard" : "Stádas aimsire i do dheais",
    "Weather status integrated in the Dashboard app.\n    The geographic location can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Stádas aimsire comhtháite san aip Deais.\nIs féidir an suíomh geografach a chinneadh go huathoibríoch nó a shainiú de láimh. Taispeántar réamhaisnéis 6 huaire ansin.\nIs féidir an stádas seo a chomhtháthú in áiteanna eile ar nós an aip Féilire.",
    "Detect location" : "Braith suíomh",
    "Set custom address" : "Socraigh seoladh saincheaptha",
    "Favorites" : "Ceanáin",
    "{temperature} {unit} clear sky later today" : "{temperature} {unit} spéir shoiléir níos déanaí inniu",
    "{temperature} {unit} clear sky" : "{temperature} {unit} spéir shoiléir",
    "{temperature} {unit} cloudy later today" : "{temperature} {unit} scamallach níos déanaí inniu",
    "{temperature} {unit} cloudy" : "{temperature} {unit} scamallach",
    "{temperature} {unit} snow and thunder later today" : "{temperature} {unit} sneachta agus toirneach níos déanaí inniu",
    "{temperature} {unit} snow and thunder" : "{temperature} {unit} sneachta agus toirneach",
    "{temperature} {unit} snow showers and thunder later today" : "{temperature} {unit} ceathanna sneachta agus toirneach níos déanaí inniu",
    "{temperature} {unit} snow showers and thunder" : "{temperature} {unit} cithfholcadáin sneachta agus toirneach",
    "{temperature} {unit} snow showers, thunder and polar twilight later today" : "{temperature} {unit} cithfholcadáin sneachta, toirneach agus gealbhan gealaí níos déanaí inniu",
    "{temperature} {unit} snow showers, thunder and polar twilight" : "{temperature} {unit} cithfholcadáin sneachta, toirneach agus gealbhan gealaí",
    "{temperature} {unit} snow showers later today" : "{temperature} {unit} ceathanna sneachta níos déanaí inniu",
    "{temperature} {unit} snow showers" : "{temperature} {unit} ceathanna sneachta",
    "{temperature} {unit} snow showers and polar twilight later today" : "{temperature} {unit} cithfholcadáin sneachta agus feannadh geal níos déanaí inniu",
    "{temperature} {unit} snow showers and polar twilight" : "{temperature} {unit}cithfholcadáin sneachta agus gealbhruthach",
    "{temperature} {unit} snow later today" : "{temperature} {unit} sneachta níos déanaí inniu",
    "{temperature} {unit} snow" : "{temperature} {unit} sneachta",
    "{temperature} {unit} fair weather later today" : "{temperature} {unit} aimsir chothrom níos déanaí inniu",
    "{temperature} {unit} fair weather" : "{temperature} {unit} aimsir chothrom",
    "{temperature} {unit} partly cloudy later today" : "{temperature} {unit} beagán scamallach níos déanaí inniu",
    "{temperature} {unit} partly cloudy" : "{temperature} {unit} breacscamallach",
    "{temperature} {unit} foggy later today" : "{temperature} {unit} ceo níos déanaí inniu",
    "{temperature} {unit} foggy" : "{temperature} {unit} ceo",
    "{temperature} {unit} light rainfall later today" : "{temperature} {unit} báisteach éadrom níos déanaí inniu",
    "{temperature} {unit} light rainfall" : "{temperature} {unit} báisteach éadrom",
    "{temperature} {unit} rainfall later today" : "{temperature} {unit} báisteach níos déanaí inniu",
    "{temperature} {unit} rainfall" : "{temperature} {unit} báistí",
    "{temperature} {unit} heavy rainfall later today" : "{temperature} {unit} báisteach throm níos déanaí inniu",
    "{temperature} {unit} heavy rainfall" : "{temperature} {unit} báisteach throm",
    "{temperature} {unit} rainfall showers later today" : "{temperature} {unit} ceathanna báistí níos déanaí inniu",
    "{temperature} {unit} rainfall showers" : "{temperature} {unit} ceathanna báistí",
    "{temperature} {unit} light rainfall showers later today" : "{temperature} {unit} ceathanna báistí éadrom níos déanaí inniu",
    "{temperature} {unit} light rainfall showers" : "{temperature} {unit} cithfholcadáin báistí éadrom",
    "{temperature} {unit} heavy rainfall showers later today" : "{temperature} {unit} cithfholcadáin báistí trom níos déanaí inniu",
    "{temperature} {unit} heavy rainfall showers" : "{temperature} {unit} cithfholcadáin báistí trom",
    "More weather for {adr}" : "Tuilleadh aimsire le haghaidh {adr}",
    "Loading weather" : "Aimsir á lódáil",
    "Set location for weather" : "Socraigh suíomh don aimsir",
    "Remove from favorites" : "Bain ó cheanáin",
    "Add as favorite" : "Cuir mar is fearr leat",
    "You are not logged in." : "Níl tú logáilte isteach.",
    "There was an error getting the weather status information." : "Tharla earráid agus an t-eolas ar stádas aimsire á fáil.",
    "No weather information found" : "Níor aimsíodh aon eolas aimsire",
    "Location not found" : "Suíomh gan aimsiú",
    "There was an error setting the location address." : "Tharla earráid agus an seoladh suímh á shocrú.",
    "There was an error setting the location." : "Tharla earráid agus an suíomh á shocrú.",
    "There was an error saving the mode." : "Tharla earráid agus an mód á shábháil.",
    "There was an error using personal address." : "Tharla earráid agus seoladh pearsanta á úsáid.",
    "Unknown weather code" : "Cód anaithnid aimsire"
},
"nplurals=5; plural=(n==1 ? 0 : n==2 ? 1 : n<7 ? 2 : n<11 ? 3 : 4);");
